@@ -11,7 +11,7 @@ SEXP nro_diffuse(SEXP topo_R, SEXP sigma_R, SEXP bmus_R, SEXP data_R);
 SEXP nro_figure(SEXP fname_R, SEXP data_R, SEXP bbox_R, SEXP script_R);
 SEXP nro_kohonen(SEXP seeds_R, SEXP rho_R, SEXP sigma_R);
 SEXP nro_label(SEXP topo_R, SEXP data_R, SEXP binflags_R, SEXP sigma_R);
-SEXP nro_match(SEXP codebook_R, SEXP data_R);
+SEXP nro_match(SEXP codebook_R, SEXP data_R, SEXP eq_R);
 SEXP nro_permute(SEXP topo_R, SEXP sigma_R, SEXP bmus_R, SEXP data_R, SEXP numcycl_R, SEXP lag_R);
 SEXP nro_train(SEXP topo_R, SEXP sigma_R, SEXP codebook_R, SEXP data_R, SEXP nsub_R, SEXP eq_R, SEXP lag_R);
 SEXP nro_webpage(SEXP fname_R, SEXP bytes_R);
@@ -26,7 +26,7 @@ R_CallMethodDef callMethods[]  = {
   {"nro_figure", (DL_FUNC) &nro_figure, 4},
   {"nro_kohonen", (DL_FUNC) &nro_kohonen, 3},
   {"nro_label", (DL_FUNC) &nro_label, 4},
-  {"nro_match", (DL_FUNC) &nro_match, 2},
+  {"nro_match", (DL_FUNC) &nro_match, 3},
   {"nro_permute", (DL_FUNC) &nro_permute, 6},
   {"nro_train", (DL_FUNC) &nro_train, 7},
   {"nro_webpage", (DL_FUNC) &nro_webpage, 2},
