@@ -10,8 +10,8 @@ bool
 medusa::closefile(FILE* fid) {
   if((FileBuffer::handles).count(fid) < 1)
     panic("Invalid stream.\n", __FILE__, __LINE__);
-  fclose(fid);
-  free(FileBuffer::handles[fid]);
+  char* buffer = FileBuffer::handles[fid];
   (FileBuffer::handles).erase(fid);
+  fclose(fid); free(buffer);
   return true;
 }
